<?php

defined( 'ABSPATH' ) or exit;
// settings values
$site_has_fixed_header = BULLETINWP::instance()->sql->get_option( 'site_has_fixed_header' );
$bulletin_background_color_default = BULLETINWP::instance()->sql->get_option( 'bulletin_background_color_default' );
$bulletin_font_color_default = BULLETINWP::instance()->sql->get_option( 'bulletin_font_color_default' );
// Default values
isset( $id ) or $id = '';
isset( $link ) or $link = '';
isset( $is_activated ) or $is_activated = false;
isset( $title ) or $title = BULLETINWP::instance()->helpers->get_default_bulletin_title();
isset( $content ) or $content = '';
isset( $mobile_content ) or $mobile_content = '';
isset( $placement ) or $placement = 'top';
isset( $header_banner_style ) or $header_banner_style = 'above-header';
isset( $header_banner_scroll ) or $header_banner_scroll = 'static';
isset( $content_max_width ) or $content_max_width = '';
isset( $text_alignment ) or $text_alignment = 'center';
isset( $font_size ) or $font_size = '';
isset( $font_size_mobile ) or $font_size_mobile = '';
isset( $text_vertical_padding ) or $text_vertical_padding = '';

if ( isset( $background_color ) ) {
    $background_color = $background_color;
} elseif ( !isset( $background_color ) && !empty($bulletin_background_color_default) ) {
    $background_color = $bulletin_background_color_default;
} else {
    $background_color = '#d33b19';
}


if ( isset( $font_color ) ) {
    $font_color = $font_color;
} else {
    
    if ( !isset( $font_color ) && !empty($bulletin_font_color_default) ) {
        $font_color = $bulletin_font_color_default;
    } else {
        $font_color = '#ffffff';
    }

}

// Visible but disabled
isset( $is_multiple_messages ) or $is_multiple_messages = false;
isset( $add_button ) or $add_button = false;
isset( $is_dismissable ) or $is_dismissable = false;
isset( $add_icon ) or $add_icon = 'none';
isset( $add_image ) or $add_image = false;
isset( $fonts ) or $fonts = 'inherit';
isset( $placement_by_content ) or $placement_by_content = 'everywhere';
isset( $placement_by_user ) or $placement_by_user = 'everyone';
isset( $add_countdown ) or $add_countdown = false;
isset( $additional_css ) or $additional_css = '';
// Images directory
$images_dir = plugin_dir_url( BULLETINWP__FILE__ ) . 'admin/images';
// Button label
$button_status = ( empty($id) ? 'publish' : 'edit' );
$default_label = ( empty($id) ? esc_html__( 'Publish Bulletin', 'bulletinwp' ) : esc_html__( 'Save Bulletin', 'bulletinwp' ) );
$loading_label = (( empty($id) ? esc_html__( 'Publishing', 'bulletinwp' ) : esc_html__( 'Saving', 'bulletinwp' ) )) . '...';
?>

<div class="mb-8">
  <div class="mb-4">
    <label class="heading mb-0 mr-2" for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-title' ) ;
?>"><?php 
esc_html_e( 'Title', 'bulletinwp' );
?></label>
    <span class="text-xs"><?php 
esc_html_e( '(only visible for you)', 'bulletinwp' );
?></span>
  </div>

  <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-title' ) ;
?>"
         class="w-full"
         type="text"
         name="bulletinTitle"
         value="<?php 
echo  esc_attr( $title ) ;
?>"
         placeholder="<?php 
echo  esc_attr( esc_html__( 'Add title', 'bulletinwp' ) ) ;
?>"
  />
</div>

<div class="content">
  <div class="left-content">

    <!-- Choose bulletin type -->
    <div class="box-container p-4 md:p-8">
      <h3 class="mb-4"><?php 
esc_html_e( 'Choose bulletin type', 'bulletinwp' );
?></h3>

      <div class="radio-group-wrapper flex flex-wrap -mx-4">
        <div class="w-1/2 lg:w-auto mr-4 radio-group">
          <div class="bulletin-type-wrapper">
            <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-top' ) ;
?>"
                   type="radio"
                   name="placement"
                   value="top"
                   data-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-display-type-header-note-element, #' . BULLETINWP_PLUGIN_SLUG . '-display-header-top-option, #' . BULLETINWP_PLUGIN_SLUG . '-display-header-top-scroll-type' ) ;
?>"
                   <?php 
checked( $placement === 'top' );
?>
            />

            <label for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-top' ) ;
?>">
              <div class="type-name"><?php 
esc_html_e( 'Header', 'bulletinwp' );
?></div>

              <div class="bulletin-type-image">
                <div class="border"></div>
                <div class="checked-icon">
                  <img src="<?php 
echo  esc_url( $images_dir . '/checked.svg' ) ;
?>" alt="">
                </div>
                <img src="<?php 
echo  esc_url( $images_dir . '/tooltips/tooltip-header.svg' ) ;
?>" alt="">
              </div>
            </label>
          </div>
        </div>

        <div class="w-1/2 lg:w-auto mr-4 radio-group">
          <div class="bulletin-type-wrapper">
            <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-float-bottom' ) ;
?>"
                   type="radio"
                   name="placement"
                   value="float-bottom"
                   data-show-elements=""
                   data-hide-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-display-type-header-note-element, #' . BULLETINWP_PLUGIN_SLUG . '-display-header-top-option, #' . BULLETINWP_PLUGIN_SLUG . '-display-header-top-scroll-type' ) ;
?>"
                   <?php 
checked( $placement === 'float-bottom' );
?>
            />

            <label for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-float-bottom' ) ;
?>">
              <div class="type-name"><?php 
esc_html_e( 'Floating at bottom', 'bulletinwp' );
?></div>

              <div class="bulletin-type-image">
                <div class="border"></div>
                <div class="checked-icon">
                  <img src="<?php 
echo  esc_url( $images_dir . '/checked.svg' ) ;
?>" alt="">
                </div>
                <img src="<?php 
echo  esc_url( $images_dir . '/tooltips/tooltip-floating.svg' ) ;
?>" alt="">
              </div>
            </label>
          </div>
        </div>

        <div class="w-1/2 lg:w-auto mr-4 radio-group">
          <div class="bulletin-type-wrapper">
            <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-sticky-footer' ) ;
?>"
                   type="radio"
                   name="placement"
                   value="sticky-footer"
                   data-show-elements=""
                   data-hide-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-display-type-header-note-element, #' . BULLETINWP_PLUGIN_SLUG . '-display-header-top-option, #' . BULLETINWP_PLUGIN_SLUG . '-display-header-top-scroll-type' ) ;
?>"
                   <?php 
checked( $placement === 'sticky-footer' );
?>
            />

            <label for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-sticky-footer' ) ;
?>">
              <div class="type-name"><?php 
esc_html_e( 'Sticky footer', 'bulletinwp' );
?></div>

              <div class="bulletin-type-image">
                <div class="border"></div>
                <div class="checked-icon">
                  <img src="<?php 
echo  esc_url( $images_dir . '/checked.svg' ) ;
?>" alt="">
                </div>
                <img src="<?php 
echo  esc_url( $images_dir . '/tooltips/tooltip-sticky.svg' ) ;
?>" alt="">
              </div>
            </label>
          </div>
        </div>

        <div class="w-1/2 lg:w-auto radio-group <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>">
          <div class="bulletin-type-wrapper">
            <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-corner' ) ;
?>"
                   type="radio"
                   name="placement"
                   value="<?php 
echo  ( bulletinwp_fs()->is__premium_only() ? 'corner' : '' ) ;
?>"
                   data-show-elements="<?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '#' . BULLETINWP_PLUGIN_SLUG . '-display-corner-option,' : '' ) ) ;
?> <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '#' . BULLETINWP_PLUGIN_SLUG . '-placement-corner-note' : '' ) ) ;
?>"
                   data-hide-elements="<?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '#' . BULLETINWP_PLUGIN_SLUG . '-text-alignment,' : '' ) ) ;
?> <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '#' . BULLETINWP_PLUGIN_SLUG . '-default-placement-note,' : '' ) ) ;
?> <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '#' . BULLETINWP_PLUGIN_SLUG . '-text-vertical-padding-wrapper,' : '' ) ) ;
?> <?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-display-type-header-note-element' ) ;
?> <?php 
echo  esc_attr( ', #' . BULLETINWP_PLUGIN_SLUG . '-display-header-top-option' ) ;
?> <?php 
echo  esc_attr( ', #' . BULLETINWP_PLUGIN_SLUG . '-display-header-top-scroll-type' ) ;
?>, <?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-add-image-wrapper' ) ;
?>"
                   <?php 
checked( $placement === 'corner' );
?>
                   <?php 
echo  esc_html( ( bulletinwp_fs()->is__premium_only() ? '' : 'disabled' ) ) ;
?>
            />

            <label for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-corner' ) ;
?>">
              <div class="type-name flex items-center justify-center">
                <?php 
esc_html_e( 'Corner', 'bulletinwp' );
?>

                <?php 
?>
                  <div class="pro-pill">PRO</div>
                <?php 
?>
              </div>

              <div class="bulletin-type-image">
                <div class="border"></div>
                <div class="checked-icon">
                  <img src="<?php 
echo  esc_url( $images_dir . '/checked.svg' ) ;
?>" alt="">
                </div>
                <img src="<?php 
echo  esc_url( $images_dir . '/tooltips/tooltip-corner.svg' ) ;
?>" alt="">
              </div>
            </label>
          </div>
        </div>

      </div>

      <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-display-type-header-note-element' ) ;
?>"
           class="mt-4"
           style="display: <?php 
echo  esc_attr( ( $placement === 'top' ? 'block' : 'none' ) ) ;
?>"
      >
        <?php 
esc_html_e( 'NOTE', 'bulletinwp' );
?>:&nbsp;<?php 
esc_html_e( 'if this site uses a fixed header, ', 'bulletinwp' );
?>
        <a href="<?php 
echo  esc_url( add_query_arg( [
    'page' => BULLETINWP_PLUGIN_SLUG . '-options-settings',
], 'admin.php' ) ) ;
?>" class="text-orange-100"><?php 
esc_html_e( 'please add the html tag in settings', 'bulletinwp' );
?></a>
      </div>
    </div>

    <!-- Tabs options -->
    <div class="mt-16">
      <div class="tabs-wrapper">
        <div class="tabs">

          <div class="tab-item active"
               data-tab="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-message-tab' ) ;
?>">
            <div class="text-base md:text-lg uppercase font-bold">
              <?php 
esc_html_e( 'Message', 'bulletinwp' );
?>
            </div>
            <div class="hidden md:block">
              <?php 
esc_html_e( 'What you want to say', 'bulletinwp' );
?>
            </div>
          </div>

          <div class="tab-item"
               data-tab="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-display-tab' ) ;
?>">
            <div class="text-base md:text-lg uppercase font-bold">
              <?php 
esc_html_e( 'Display Options', 'bulletinwp' );
?>
            </div>
            <div class="hidden md:block">
              <?php 
esc_html_e( 'How you want it to display', 'bulletinwp' );
?>
            </div>
          </div>

          <div class="tab-item"
               data-tab="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-design-tab' ) ;
?>">
            <div class="text-base md:text-lg uppercase font-bold">
              <?php 
esc_html_e( 'Design', 'bulletinwp' );
?>
            </div>
            <div class="hidden md:block">
              <?php 
esc_html_e( 'Customize your bulletin', 'bulletinwp' );
?>
            </div>
          </div>

          <div class="tab-item"
               data-tab="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-placement-tab' ) ;
?>">
            <div class="text-base md:text-lg uppercase font-bold">
              <?php 
esc_html_e( 'Placement', 'bulletinwp' );
?>
            </div>
            <div class="hidden md:block">
              <?php 
esc_html_e( 'Where you want to show it', 'bulletinwp' );
?>
            </div>
          </div>

          <div class="tab-item"
               data-tab="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-expiry-tab' ) ;
?>">
            <div class="text-base md:text-lg uppercase font-bold">
              <?php 
esc_html_e( 'Expiry', 'bulletinwp' );
?>
            </div>
            <div class="hidden md:block">
              <?php 
esc_html_e( 'Set expiry and countdown', 'bulletinwp' );
?>
            </div>
          </div>

          <div class="tab-item"
               data-tab="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-advanced-tab' ) ;
?>">
            <div class="text-base md:text-lg uppercase font-bold">
              <?php 
esc_html_e( 'Advanced', 'bulletinwp' );
?>
            </div>
            <div class="hidden md:block">
              <?php 
esc_html_e( 'Add custom CSS & more', 'bulletinwp' );
?>
            </div>
          </div>

          <?php 

if ( is_multisite() && is_main_site() ) {
    ?>
            <div class="tab-item"
                 data-tab="<?php 
    echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-network-tab' ) ;
    ?>">
              <div class="text-base md:text-lg uppercase font-bold">
                <?php 
    esc_html_e( 'WP Network', 'bulletinwp' );
    ?>
              </div>
              <div class="hidden md:block">
                <?php 
    esc_html_e( 'Configure bulletins on networks', 'bulletinwp' );
    ?>
              </div>
            </div>
          <?php 
}

?>
        </div>

        <div class="tabs-content">

          <!-- TAB - Message -->
          <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-message-tab' ) ;
?>" class="tab-pane active">
            <div class="flex items-center mb-8 md:mb-12">
              <div class="heading-icon mr-4">
                <img src="<?php 
echo  esc_url( $images_dir . '/tab-icon/message.svg' ) ;
?>" alt="">
              </div>

              <div class="tab-heading">
                <?php 
esc_html_e( 'Message', 'bulletinwp' );
?>
              </div>
            </div>

            <div class="flex items-end justify-between">
              <div class="heading">
                <?php 
esc_html_e( 'Message', 'bulletinwp' );
?>
              </div>

              <div class="text-right modal-button-wrapper relative" data-overlay=".modal-overlay" data-id-modal="#support-markdown-modal">
                <a class="modal-button cursor-pointer"><?php 
esc_html_e( 'supports markdown, emojis & links', 'bulletinwp' );
?></a>

                <div id="support-markdown-modal" class="modal opacity-0 pointer-events-none relative">
                  <div class="modal-overlay tooltip-overlay"></div>

                  <div class="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-support-markdown box-container' ) ;
?>">
                    <div class="line-indicator"></div>

                    <div class="flex my-4 border-b-2">
                      <div class="w-1/2 px-4">
                        <div class="heading"><?php 
esc_html_e( 'Enter this', 'bulletinwp' );
?></div>
                      </div>
                      <div class="w-1/2 px-4">
                        <div class="heading"><?php 
esc_html_e( 'To see this', 'bulletinwp' );
?></div>
                      </div>
                    </div>

                    <div class="flex my-4">
                      <div class="w-1/2 px-4">
                        <p class="font-couriernew">
                          **<?php 
esc_html_e( 'This is bold', 'bulletinwp' );
?>**
                        </p>
                      </div>
                      <div class="w-1/2 px-4">
                        <div class="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-markdown-items' ) ;
?>">
                          **<?php 
esc_html_e( 'This is bold', 'bulletinwp' );
?>**
                        </div>
                      </div>
                    </div>

                    <div class="flex my-4">
                      <div class="w-1/2 px-4">
                        <p class="font-couriernew">
                          *<?php 
esc_html_e( 'This is italic', 'bulletinwp' );
?>*
                        </p>
                      </div>
                      <div class="w-1/2 px-4">
                        <div class="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-markdown-items' ) ;
?>">
                          *<?php 
esc_html_e( 'This is italic', 'bulletinwp' );
?>*
                        </div>
                      </div>
                    </div>

                    <div class="flex my-4">
                      <div class="w-1/2 px-4">
                        <p class="font-couriernew">
                          [<?php 
esc_html_e( 'link text', 'bulletinwp' );
?>](https://google.com)
                        </p>
                      </div>
                      <div class="w-1/2 px-4">
                        <div class="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-markdown-items' ) ;
?>">
                          [<?php 
esc_html_e( 'link text', 'bulletinwp' );
?>](https://google.com)
                        </div>
                      </div>
                    </div>

                    <div class="flex my-4">
                      <div class="w-1/2 px-4">
                        <p class="font-couriernew">
                          <?php 
echo  esc_html( htmlspecialchars( '<a href="https://google.com" target="_blank">' ) ) ;
?>
                          <?php 
esc_html_e( 'link text', 'bulletinwp' );
?> (<?php 
esc_html_e( 'open in new tab', 'bulletinwp' );
?>)
                          <?php 
echo  esc_html( htmlspecialchars( '</a>' ) ) ;
?>
                        </p>
                      </div>
                      <div class="w-1/2 px-4">
                        <div>
                          <p>
                            <a href="https://google.com" target="_blank">
                              <?php 
esc_html_e( 'link text', 'bulletinwp' );
?> (<?php 
esc_html_e( 'open in new tab', 'bulletinwp' );
?>)
                            </a>
                          </p>
                        </div>
                      </div>
                    </div>

                    <div class="flex my-4">
                      <div class="w-1/2 px-4">
                        <p class="font-couriernew">
                          <?php 
esc_html_e( 'paste codes', 'bulletinwp' );
?> `<?php 
esc_html_e( 'with backticks', 'bulletinwp' );
?>`
                        </p>
                      </div>
                      <div class="w-1/2 px-4">
                        <div class="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-markdown-item' ) ;
?>">
                          <?php 
esc_html_e( 'paste codes', 'bulletinwp' );
?> `<?php 
esc_html_e( 'with backticks', 'bulletinwp' );
?>`
                        </div>
                      </div>
                    </div>

                    <div class="flex my-4">
                      <div class="w-1/2 px-4">
                        <p class="font-couriernew">:grin:</p>
                        <div class="text-left">
                          <a href="https://gist.github.com/rxaviers/7360908" target="_blank">
                            <?php 
esc_html_e( 'view full list of emoji commands', 'bulletinwp' );
?>
                          </a>
                        </div>
                      </div>
                      <div class="w-1/2 px-4">
                        <div class="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-markdown-item' ) ;
?>">:grin:</div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>

            <hr class="my-4">

            <div class="flex flex-wrap -mx-4">
              <div class="form-field form-field-text w-full lg:w-1/2 mb-4 lg:mb-0 px-4 is-required">
                <label class="mb-2" for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-content' ) ;
?>">
                  <?php 
esc_html_e( 'Tablet and up', 'bulletinwp' );
?>
                </label>
                <textarea id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-content' ) ;
?>"
                          class="form-input textarea-input w-full"
                          type="text"
                          name="content"
                          placeholder=""
                ><?php 
echo  esc_textarea( $content ) ;
?></textarea>
              </div>

              <div class="form-field form-field-text w-full lg:w-1/2 mb-4 lg:mb-0 px-4">
                <label class="mb-2" for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-mobile-content' ) ;
?>">
                  <?php 
esc_html_e( 'Mobile only (optional)', 'bulletinwp' );
?>
                </label>
                <textarea id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-mobile-content' ) ;
?>"
                          class="form-input textarea-input w-full"
                          type="text"
                          name="mobileContent"
                          placeholder=""
                ><?php 
echo  esc_textarea( $mobile_content ) ;
?></textarea>
              </div>
            </div>

            <div class="mt-8">
              <div class="heading flex items-center">
                <?php 
esc_html_e( 'Add multiple messages', 'bulletinwp' );
?>

                <?php 
?>
                  <div class="pro-pill">PRO</div>
                <?php 
?>
              </div>

              <hr class="my-4">

              <!-- Toggle -->
              <div class="checkbox-wrapper toggle-switch <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>"
                   data-checked-label="<?php 
echo  esc_attr( esc_html__( 'Yes', 'bulletinwp' ) ) ;
?>"
                   data-unchecked-label="<?php 
echo  esc_attr( esc_html__( 'No', 'bulletinwp' ) ) ;
?>"
                   data-hide-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-messages-element, #' . BULLETINWP_PLUGIN_SLUG . '-rotation-style-element' ) ;
?>"
              >
                <input type="checkbox" name="isMultipleMessages" <?php 
checked( $is_multiple_messages );
?> />
                <span class="label"><?php 
echo  esc_html( ( $is_multiple_messages ? esc_html__( 'Yes', 'bulletinwp' ) : esc_html__( 'No', 'bulletinwp' ) ) ) ;
?></span>
              </div>

              <?php 
?>
            </div>

            <div class="mt-8">
              <div class="heading flex items-center">
                <?php 
esc_html_e( 'Add button', 'bulletinwp' );
?>

                <?php 
?>
                  <div class="pro-pill">PRO</div>
                <?php 
?>
              </div>

              <hr class="my-4">

              <div class="checkbox-wrapper toggle-switch <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>"
                   data-checked-label="<?php 
esc_html_e( 'Yes', 'bulletinwp' );
?>"
                   data-unchecked-label="<?php 
esc_html_e( 'No', 'bulletinwp' );
?>"
                   data-hide-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-button-elements' ) ;
?>"
              >
                <input type="checkbox" name="addButton" <?php 
checked( $add_button );
?> />
                <span class="label"><?php 
echo  esc_html( ( $add_button ? esc_html__( 'Yes', 'bulletinwp' ) : esc_html__( 'No', 'bulletinwp' ) ) ) ;
?></span>
              </div>

              <?php 
?>
            </div>

            <!-- Allow user to dismiss -->
            <div class="mt-8">
              <div class="heading flex items-center">
                <?php 
esc_html_e( 'Allow user to dismiss bulletin?', 'bulletinwp' );
?>

                <?php 
?>
                  <div class="pro-pill">PRO</div>
                <?php 
?>
              </div>

              <hr class="my-4">

              <div class="checkbox-wrapper toggle-switch <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>"
                   data-checked-label="<?php 
esc_html_e( 'Yes', 'bulletinwp' );
?>"
                   data-unchecked-label="<?php 
esc_html_e( 'No', 'bulletinwp' );
?>"

                   data-hide-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-cookie-expiry-element' ) ;
?>"
              >
                <input type="checkbox" name="isDismissable" <?php 
checked( $is_dismissable );
?> />
                <span class="label"><?php 
echo  esc_html( ( $is_dismissable ? esc_html__( 'Yes', 'bulletinwp' ) : esc_html__( 'No', 'bulletinwp' ) ) ) ;
?></span>
              </div>

              <?php 
?>
            </div>

          </div>

          <!-- TAB - Display -->
          <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-display-tab' ) ;
?>" class="tab-pane">
            <div class="flex items-center mb-8 md:mb-12">
              <div class="heading-icon mr-4">
                <img src="<?php 
echo  esc_url( $images_dir . '/tab-icon/message.svg' ) ;
?>" alt="">
              </div>

              <div class="tab-heading">
                <?php 
esc_html_e( 'Display options', 'bulletinwp' );
?>
              </div>
            </div>

            <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-display-header-top-option' ) ;
?>"
                 class="mt-4 "
                 style="display: <?php 
echo  esc_attr( ( $placement === 'top' ? 'block' : 'none' ) ) ;
?>"
            >

              <div class="heading"><?php 
esc_html_e( 'Header banner display', 'bulletinwp' );
?></div>

              <hr class="my-4">

              <div class="radio-group-wrapper flex">
                <div class="mr-4">
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-header-banner-above' ) ;
?>"
                           type="radio"
                           name="headerBannerStyle"
                           value="above-header"
                           <?php 
checked( $header_banner_style === 'above-header' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Above header', 'bulletinwp' );
?></span>
                  </label>
                </div>

                <div>
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-header-banner-below' ) ;
?>"
                           type="radio"
                           name="headerBannerStyle"
                           value="below-header"
                           <?php 
checked( $header_banner_style === 'below-header' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Below header', 'bulletinwp' );
?></span>
                  </label>
                </div>
              </div>
            </div>

            <?php 

if ( $site_has_fixed_header ) {
    ?>
              <div id="<?php 
    echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-display-header-top-scroll-type' ) ;
    ?>"
                   class="mt-8"
                   style="display: <?php 
    echo  esc_attr( ( $placement === 'top' ? 'block' : 'none' ) ) ;
    ?>">

                <div class="heading mb-2"><?php 
    esc_html_e( 'Header banner scroll type', 'bulletinwp' );
    ?></div>

                <div class="radio-group-wrapper flex">
                  <div class="mr-4">
                    <label class="radio-wrapper">
                      <input id="<?php 
    echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-header-banner-scroll-static' ) ;
    ?>"
                             type="radio"
                             name="headerBannerScroll"
                             value="static"
                             <?php 
    checked( $header_banner_scroll === 'static' );
    ?>
                      />
                      <span class="thumb"></span>
                      <span><?php 
    esc_html_e( 'Static', 'bulletinwp' );
    ?></span>
                    </label>
                  </div>

                  <div>
                    <label class="radio-wrapper">
                      <input id="<?php 
    echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-header-banner-scroll-fixed' ) ;
    ?>"
                             type="radio"
                             name="headerBannerScroll"
                             value="fixed"
                             <?php 
    checked( $header_banner_scroll === 'fixed' );
    ?>
                      />
                      <span class="thumb"></span>
                      <span><?php 
    esc_html_e( 'Fixed', 'bulletinwp' );
    ?></span>
                    </label>
                  </div>
                </div>
              </div>
            <?php 
}

?>

            <?php 
?>

            <div class="mt-8">
              <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-default-placement-note' ) ;
?>"
                   style="display: <?php 
echo  esc_attr( ( $placement !== 'corner' ? 'block' : 'none' ) ) ;
?>">
                <span class="heading mr-2"><?php 
esc_html_e( 'Content max-width', 'bulletinwp' );
?></span>
                <span class="text-xs"><?php 
esc_html_e( '(in px, leave blank for 100% width)', 'bulletinwp' );
?></span>
              </div>

              <?php 
?>

              <hr class="my-4">

              <div>
                <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-content-max-width' ) ;
?>"
                       type="number"
                       name="contentMaxWidth"
                       value="<?php 
echo  esc_attr( $content_max_width ) ;
?>"
                       placeholder=""
                />
              </div>
            </div>

            <div class="mt-8">
              <div class="heading mb-2"><?php 
esc_html_e( 'Text alignment', 'bulletinwp' );
?></div>

              <hr class="my-4">

              <div class="flex">
                <div class="mr-4">
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-text-alignment-center' ) ;
?>"
                           type="radio"
                           name="textAlignment"
                           value="center"
                           <?php 
checked( $text_alignment === 'center' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Center', 'bulletinwp' );
?></span>
                  </label>
                </div>

                <div class="mr-4">
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-text-alignment-left' ) ;
?>"
                           type="radio"
                           name="textAlignment"
                           value="left"
                           <?php 
checked( $text_alignment === 'left' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Left', 'bulletinwp' );
?></span>
                  </label>
                </div>

                <div>
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-text-alignment-right' ) ;
?>"
                           type="radio"
                           name="textAlignment"
                           value="right"
                           <?php 
checked( $text_alignment === 'right' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Right', 'bulletinwp' );
?></span>
                  </label>
                </div>
              </div>
            </div>
          </div>

          <!-- TAB - Design -->
          <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-design-tab' ) ;
?>" class="tab-pane">
            <div class="flex items-center mb-8 md:mb-12">
              <div class="heading-icon mr-4">
                <img src="<?php 
echo  esc_url( $images_dir . '/tab-icon/message.svg' ) ;
?>" alt="">
              </div>

              <div class="tab-heading">
                <?php 
esc_html_e( 'Design', 'bulletinwp' );
?>
              </div>
            </div>

            <div>
              <div class="heading">
                <?php 
esc_html_e( 'Colors', 'bulletinwp' );
?>
              </div>

              <hr class="my-4">

              <div class="flex flex-col md:flex-row mb-4">
                <div class="form-field form-field-color-picker flex flex-col mr-0 md:mr-4 mb-4 md:mb-0 is-required">
                  <label class="mb-2" for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-background-color' ) ;
?>"><?php 
_e( 'Background color', 'bulletinwp' );
?></label>
                  <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-background-color' ) ;
?>"
                          class="form-input color-picker-input"
                          type="text"
                          name="backgroundColor"
                          value="<?php 
echo  esc_attr( $background_color ) ;
?>"
                          placeholder=""
                          data-default-color=""
                  />
                </div>

                <div class="form-field form-field-color-picker flex flex-col is-required">
                  <label class="mb-2" for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-font-color' ) ;
?>"><?php 
_e( 'Font color', 'bulletinwp' );
?></label>
                  <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-font-color' ) ;
?>"
                          class="form-input color-picker-input"
                          type="text"
                          name="fontColor"
                          value="<?php 
echo  esc_attr( $font_color ) ;
?>"
                          placeholder=""
                          data-default-color=""
                  />
                </div>
              </div>
            </div>

            <div class="mt-8">
              <div>
                <span class="heading mr-2"> <?php 
esc_html_e( 'Font Size', 'bulletinwp' );
?> </span>
                <span class="text-xs"><?php 
esc_html_e( '(in px, leave blank for default font-size)', 'bulletinwp' );
?></span>
              </div>

              <hr class="my-4">

              <div class="flex flex-wrap -mx-4 mb-8">
                <div class="w-full lg:w-auto mb-4 lg:mb-0 px-4">
                  <label for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-font-size' ) ;
?>"><?php 
esc_html_e( 'Desktop', 'bulletinwp' );
?></label>
                  <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-font-size' ) ;
?>"
                         class="w-full"
                         type="number"
                         name="fontSize"
                         value="<?php 
echo  esc_attr( $font_size ) ;
?>"
                         placeholder="16"
                  />
                </div>

                <div class="w-full lg:w-auto mb-4 lg:mb-0 px-4">
                  <label for="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-mobile-font-size' ) ;
?>"><?php 
esc_html_e( 'Mobile', 'bulletinwp' );
?></label>
                  <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-mobile-font-size' ) ;
?>"
                         class="w-full"
                         type="number"
                         name="fontSizeMobile"
                         value="<?php 
echo  esc_attr( $font_size_mobile ) ;
?>"
                         placeholder="16"
                  />
                </div>
              </div>
            </div>

            <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-text-vertical-padding-wrapper' ) ;
?>"
              class="mt-8">
              <div>
                <span class="heading mr-2"> <?php 
esc_html_e( 'Text Vertical Padding', 'bulletinwp' );
?> </span>
                <span class="text-xs"><?php 
esc_html_e( '(in px, leave blank for default vertical padding)', 'bulletinwp' );
?></span>
              </div>

              <hr class="my-4">

              <div class="flex flex-wrap -mx-4">
                <div class="w-full lg:w-auto mb-4 lg:mb-0 px-4">
                  <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-text-vertical-padding' ) ;
?>"
                         class="w-full"
                         type="number"
                         name="textVerticalPadding"
                         value="<?php 
echo  esc_attr( $text_vertical_padding ) ;
?>"
                         placeholder="12"
                  />
                </div>
              </div>
            </div>

            <!-- ADD ICON -->
            <div class="mt-8">
              <div class="heading flex items-center">
                <?php 
esc_html_e( 'Add icon', 'bulletinwp' );
?>

                <?php 
?>
                  <div class="pro-pill">PRO</div>
                <?php 
?>
              </div>

              <hr class="my-4">

              <!-- Radio Group -->
              <div class="radio-group-wrapper flex mb-4 <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>">
                <div class="mr-4">
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-add-icon-none' ) ;
?>"
                           type="radio"
                           name="addIcon"
                           value="none"
                           data-show-elements=""
                           <?php 
checked( $add_icon === 'none' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'None', 'bulletinwp' );
?></span>
                  </label>
                </div>

                <div class="mr-4">
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-add-icon-from-set' ) ;
?>"
                           type="radio"
                           name="addIcon"
                           value="from-set"
                           data-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-icon-from-set-element' ) ;
?>"
                           <?php 
checked( $add_icon === 'from-set' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'From a set', 'bulletinwp' );
?></span>
                  </label>
                </div>

                <div>
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-add-icon-upload-own' ) ;
?>"
                           type="radio"
                           name="addIcon"
                           value="upload-own"
                           data-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-upload-icon-element' ) ;
?>"
                           <?php 
checked( $add_icon === 'upload-own' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Upload my own', 'bulletinwp' );
?></span>
                  </label>
                </div>
              </div>

              <?php 
?>
            </div>

            <!-- ADD IMAGE -->
            <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-add-image-wrapper' ) ;
?>"
                 class="mt-8"
                 style="display: <?php 
echo  esc_attr( ( $placement !== 'corner' ? 'block' : 'none' ) ) ;
?>;"
            >
              <div class="heading flex items-center">
                <?php 
esc_html_e( 'Add image', 'bulletinwp' );
?>

                <?php 
?>
                  <div class="pro-pill">PRO</div>
                <?php 
?>
              </div>

              <hr class="my-4">

              <!-- Toggle -->
              <div class="checkbox-wrapper toggle-switch <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>"
                   data-checked-label="<?php 
echo  esc_attr( esc_html__( 'Yes', 'bulletinwp' ) ) ;
?>"
                   data-unchecked-label="<?php 
echo  esc_attr( esc_html__( 'No', 'bulletinwp' ) ) ;
?>"
                   data-hide-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-upload-image-element' ) ;
?>, #<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-image-alignment-element' ) ;
?>, #<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-image-max-width-element' ) ;
?>"
              >
                <input type="checkbox" name="addImage" <?php 
checked( $add_image );
?> />
                <span class="label"><?php 
echo  esc_html( ( $add_image ? esc_html__( 'Yes', 'bulletinwp' ) : esc_html__( 'No', 'bulletinwp' ) ) ) ;
?></span>
              </div>

              <?php 
?>
            </div>

            <!-- FONTS -->
            <div class="mt-8">
              <div class="heading flex items-center">
                <?php 
esc_html_e( 'Fonts', 'bulletinwp' );
?>

                <?php 
?>
                  <div class="pro-pill">PRO</div>
                <?php 
?>
              </div>

              <hr class="my-4">

              <!-- Radio group -->
              <div class="radio-group-wrapper flex mb-4 <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>">
                <div class="mr-4">
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-fonts-inherit' ) ;
?>"
                           type="radio"
                           name="fonts"
                           value="inherit"
                           <?php 
checked( $fonts === 'inherit' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Inherit from site', 'bulletinwp' );
?></span>
                  </label>
                </div>

                <div class="mr-4">
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-fonts-google-fonts' ) ;
?>"
                           type="radio"
                           name="fonts"
                           value="google-fonts"
                           data-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-google-fonts-element' ) ;
?>"
                           <?php 
checked( $fonts === 'google-fonts' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Google fonts', 'bulletinwp' );
?></span>
                  </label>
                </div>
              </div>

              <?php 
?>
            </div>

          </div>

          <!-- TAB - Placement -->
          <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-tab' ) ;
?>" class="tab-pane">
            <div class="flex items-center mb-8 md:mb-12">
              <div class="heading-icon mr-4">
                <img src="<?php 
echo  esc_url( $images_dir . '/tab-icon/message.svg' ) ;
?>" alt="">
              </div>

              <div class="tab-heading">
                <?php 
esc_html_e( 'Placement', 'bulletinwp' );
?>
              </div>
            </div>

            <!-- Actual Pro Feat -->
            <div class="heading flex items-center">
              <?php 
esc_html_e( 'By content', 'bulletinwp' );
?>

              <?php 
?>
                <div class="pro-pill">PRO</div>
              <?php 
?>
            </div>

            <hr class="my-4">

            <div class="radio-group-wrapper flex <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>">
              <div class="mr-4">
                <label class="radio-wrapper">
                  <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-by-content-everywhere' ) ;
?>"
                         type="radio"
                         name="placementByContent"
                         value="everywhere"
                         <?php 
checked( $placement_by_content === 'everywhere' );
?>
                  />
                  <span class="thumb"></span>
                  <span><?php 
esc_html_e( 'Show everywhere', 'bulletinwp' );
?></span>
                </label>
              </div>

              <div>
                <label class="radio-wrapper">
                  <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-by-content-selected-content' ) ;
?>"
                         type="radio"
                         name="placementByContent"
                         value="selected-content"
                         data-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-placement-selected-content-include-element' ) ;
?>, #<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-selected-content-exclude-element' ) ;
?>"
                         <?php 
checked( $placement_by_content === 'selected-content' );
?>
                  />
                  <span class="thumb"></span>
                  <span><?php 
esc_html_e( 'Show only on certain content', 'bulletinwp' );
?></span>
                </label>
              </div>
            </div>

            <?php 
?>

            <div class="mt-8">
              <div class="heading flex items-center">
                <?php 
esc_html_e( 'By user', 'bulletinwp' );
?>

                <?php 
?>
                  <div class="pro-pill">PRO</div>
                <?php 
?>
              </div>

              <hr class="my-4">

              <div class="radio-group-wrapper flex <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>">
                <div class="mr-4">
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-by-user-everyone' ) ;
?>"
                           type="radio"
                           name="placementByUser"
                           value="everyone"
                           <?php 
checked( $placement_by_user === 'everyone' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Show for everyone', 'bulletinwp' );
?></span>
                  </label>
                </div>

                <div class="mr-4">
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-by-user-logged-in-users' ) ;
?>"
                           type="radio"
                           name="placementByUser"
                           value="logged-in-users"
                           <?php 
checked( $placement_by_user === 'logged-in-users' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Only logged-in users', 'bulletinwp' );
?></span>
                  </label>
                </div>

                <div>
                  <label class="radio-wrapper">
                    <input id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-placement-by-user-cookie-value' ) ;
?>"
                           type="radio"
                           name="placementByUser"
                           value="cookie-value"
                           data-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-placement-user-cookie-value-element' ) ;
?>"
                           <?php 
checked( $placement_by_user === 'cookie-value' );
?>
                    />
                    <span class="thumb"></span>
                    <span><?php 
esc_html_e( 'Based on cookie value', 'bulletinwp' );
?></span>
                  </label>
                </div>
              </div>

              <?php 
?>
            </div>

          </div>

          <!-- TAB - Expiry -->
          <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-expiry-tab' ) ;
?>" class="tab-pane">
            <div class="flex items-center mb-8 md:mb-12">
              <div class="heading-icon mr-4">
                <img src="<?php 
echo  esc_url( $images_dir . '/tab-icon/message.svg' ) ;
?>" alt="">
              </div>

              <div class="tab-heading">
                <?php 
esc_html_e( 'Expiry', 'bulletinwp' );
?>
              </div>
            </div>

            <div class="heading flex items-center">
              <?php 
esc_html_e( 'Expire bulletin', 'bulletinwp' );
?>

              <?php 
?>
                <div class="pro-pill">PRO</div>
              <?php 
?>
            </div>

            <hr class="my-4">

            <div class="checkbox-wrapper toggle-switch add-countdown-data-label <?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>"
                 data-checked-label="<?php 
echo  esc_attr( esc_html__( 'Yes', 'bulletinwp' ) ) ;
?>"
                 data-unchecked-label="<?php 
echo  esc_attr( esc_html__( 'No', 'bulletinwp' ) ) ;
?>"
                 data-hide-show-elements="<?php 
echo  esc_attr( '#' . BULLETINWP_PLUGIN_SLUG . '-countdown-element' ) ;
?>"
            >
              <input type="checkbox" name="addCountdown" <?php 
checked( $add_countdown );
?> />
              <span class="label add-countdown-label"><?php 
echo  esc_html( ( $add_countdown ? esc_html__( 'Yes', 'bulletinwp' ) : esc_html__( 'No', 'bulletinwp' ) ) ) ;
?></span>
            </div>

            <?php 
?>
          </div>

          <!-- TAB - Advanced -->
          <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-advanced-tab' ) ;
?>" class="tab-pane">
            <div class="flex items-center mb-8 md:mb-12">
              <div class="heading-icon mr-4">
                <img src="<?php 
echo  esc_url( $images_dir . '/tab-icon/message.svg' ) ;
?>" alt="">
              </div>

              <div class="tab-heading">
                <?php 
esc_html_e( 'Advanced', 'bulletinwp' );
?>
              </div>
            </div>

            <div id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-additional-css-element' ) ;
?>">
              <div class="heading flex items-center">
                <?php 
esc_html_e( 'Additional CSS to render with this bulletin', 'bulletinwp' );
?>

                <?php 
?>
                  <div class="pro-pill">PRO</div>
                <?php 
?>
              </div>

              <hr class="my-4">

              <div class="<?php 
echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
?>">
                <textarea id="<?php 
echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-additional-css' ) ;
?>"
                          class="form-input textarea-input w-full"
                          name="additionalCss"
                          placeholder=""
                ><?php 
echo  esc_textarea( $additional_css ) ;
?></textarea>

                <div class="text-sm">
                  <?php 
echo  esc_html( 'i.e. #' . BULLETINWP_PLUGIN_SLUG . '-bulletin-item-' . (( !empty($id) ? $id : '1' )) . ' { ... }' ) ;
?>
                  <br />
                  <?php 
echo  esc_html( ( is_multisite() && is_main_site() ? 'for subsites: #' . BULLETINWP_PLUGIN_SLUG . '-bulletin-item-global-' . (( !empty($id) ? $id : '1' )) . ' { ... }' : '' ) ) ;
?>
                </div>
              </div>
            </div>
          </div>

          <!-- TAB - WP Network -->
          <?php 

if ( is_multisite() && is_main_site() ) {
    ?>
            <div id="<?php 
    echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-network-tab' ) ;
    ?>" class="tab-pane">
              <div class="flex items-center mb-8 md:mb-12">
                <div class="heading-icon mr-4">
                  <img src="<?php 
    echo  esc_url( $images_dir . '/tab-icon/message.svg' ) ;
    ?>" alt="">
                </div>

                <div class="tab-heading">
                  <?php 
    esc_html_e( 'WP Network', 'bulletinwp' );
    ?>
                </div>
              </div>

              <label class="heading flex items-center" for="<?php 
    echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-apply-all-subsites' ) ;
    ?>">
                <?php 
    esc_html_e( 'Apply to all subsites', 'bulletinwp' );
    ?>

                <?php 
    ?>
                  <div class="pro-pill">PRO</div>
                <?php 
    ?>
              </label>

              <hr class="my-4">

              <div class="checkbox-wrapper toggle-switch <?php 
    echo  esc_attr( ( bulletinwp_fs()->is__premium_only() ? '' : 'pro-disabled' ) ) ;
    ?>"
                   data-checked-label="<?php 
    echo  esc_attr( esc_html__( 'Yes', 'bulletinwp' ) ) ;
    ?>"
                   data-unchecked-label="<?php 
    echo  esc_attr( esc_html__( 'No', 'bulletinwp' ) ) ;
    ?>"
              >
                <input id="<?php 
    echo  esc_attr( BULLETINWP_PLUGIN_SLUG . '-apply-all-subsites' ) ;
    ?>" type="checkbox" name="applyAllSubsites" <?php 
    checked( $apply_all_subsites );
    ?> />
                <span class="label"><?php 
    echo  esc_html( ( $apply_all_subsites ? esc_html__( 'Yes', 'bulletinwp' ) : esc_html__( 'No', 'bulletinwp' ) ) ) ;
    ?></span>
              </div>
            </div>
          <?php 
}

?>
        </div>
      </div>
    </div>

    <?php 
?>
      <?php 
include_once BULLETINWP_PLUGIN_PATH . 'admin/views/common/upgrade-panel.php';
?>
    <?php 
?>
  </div>

  <div class="right-content">
    <div class="box-container py-8 px-4">
      <!-- Preview -->
      <a href="<?php 
echo  esc_url( $link ) ;
?>"
         class="btn view-button mb-8"
         target="_blank"
         style="display: <?php 
echo  esc_attr( ( !empty($link) ? 'inline-flex' : 'none' ) ) ;
?>; width: 80%;"
      >
        <?php 
echo  esc_html( ( $is_activated ? esc_html__( 'View', 'bulletinwp' ) : esc_html__( 'Preview', 'bulletinwp' ) ) ) ;
?>
        <img src="<?php 
echo  esc_url( $images_dir . '/angle.svg' ) ;
?>" alt="">
      </a>

      <!-- Active Switch -->
      <div class="mb-8">
        <div class="checkbox-wrapper toggle-switch active-data-label"
             data-checked-label="<?php 
echo  esc_attr( esc_html__( 'Active', 'bulletinwp' ) ) ;
?>"
             data-unchecked-label="<?php 
echo  esc_attr( esc_html__( 'Inactive', 'bulletinwp' ) ) ;
?>"
        >
          <input type="checkbox" name="isActivated" <?php 
checked( $is_activated );
?>  <?php 
echo  esc_html( ( $add_schedule ? 'disabled' : '' ) ) ;
?> />
          <span class="label active-switch-label"><?php 
echo  esc_html( ( $is_activated ? esc_html__( 'Active', 'bulletinwp' ) : esc_html__( 'Inactive', 'bulletinwp' ) ) ) ;
?></span>
        </div>
      </div>

      <?php 
?>

      <!-- Submit -->
      <button class="btn-fill text-lg"
              type="submit"
              data-button-status="<?php 
echo  esc_attr( $button_status ) ;
?>"
              data-default-label="<?php 
echo  esc_attr( $default_label ) ;
?>"
              data-loading-label="<?php 
echo  esc_attr( $loading_label ) ;
?>"
      >
        <?php 
echo  esc_html( $default_label ) ;
?>
      </button>
      <div class="form-message mt-8" style="display: none;"></div>
    </div>

    <!-- Right panel content -->
    <?php 
include_once BULLETINWP_PLUGIN_PATH . 'admin/views/common/right-panel.php';
?>

  </div>
</div>
